<?php
namespace Teknisa\GOP\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\Report\Strategy\BirtStrategy;
use Teknisa\Libs\Util\NewCode;
use Teknisa\GOP\Services\Gop10000CalculoOrcamentoOperacionalService;

class Gop10000CalculoOrcamentoOperacionalReport extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $reportService;
    protected $environment;
    protected $newCodeSC;
    protected $crudService;
    protected $service;

    public function __construct($reportService, $birtStrategy, $environment, $newCodeSC, $crudService, $service)
    {
        $this->reportService = $reportService;
        $this->birtStrategy = $birtStrategy;
        $this->environment = $environment;
        $this->newCodeSC = $newCodeSC;
        $this->crudService = $crudService;
        $this->service = $service;
    }
		
	protected $reportMapping = array (
		'GOP10000' => array (
			'strategy' => 'BIRT',
            'parameterMapping' => array (
            	"LFILIAL" => "P_LFILIAL",
            	"DETALHAMENTO_PRODUTO" => "DETALHAMENTO_PRODUTO",
                "NRORG" => "P_NRORG"
			)
		)
	);
	
	public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
	{
	    try {
	        $this->service->beginTransaction();
	        
            $row = $request->getRow();
            
            $row['NRORG'] = $this->environment->getNrorgTrab();
            $row['LFILIAL'] = $this->newCodeSC->getCodeByTableName('LISTA', $row['NRORG']);
            
            $this->insereLista($row['CDFILIAL'], $row['LFILIAL']);
            
            $this->birtStrategy->setReportFormat('xlsx');
            
            $this->service->commit();
	    } catch (\Exception $e) {
	        $this->service->rollback();
	        $response->setError(new Error($e->getMessage(), 500));
	    }
    }
    
    private function insereLista($rows, $nrLista)
    {
        $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
				
		foreach ($rows as $code) {
            $lista["NRLISTA"]        = $nrLista;
            $lista["CDLISTA"]        = $code;
            $lista["__is_new"]       = true;
            $lista["DTULTATULIST"]   = "";
            $lista["DTINCLUSAO"]     = $currentTime;
            $lista["DTULTATU"]       = "";
            $lista["NRORGINCLUSAO"]  = $this->environment->getNrOrgTrab();
            $lista["CDOPERINCLUSAO"] = "";
            $lista["NRORGULTATU"]    = "";
            $lista["CDOPERULTATU"]   = "";
            $lista["IDATIVO"]        = "";
            $lista["NRORG"]          = $this->environment->getNrOrgTrab();
            $lista["IDATIVO"]        = 'S';
            
            $rowsToSave[] = $lista;
		}
		
		$this->crudService->save("lista", $rowsToSave);
    }
	
    
}